@@ -16,12 +16,14 @@
 #' @importFrom rlang .data
 #'
 #' @examples
+#' \dontrun{
 #' # between 1 and 1.2 MeV, between 6 and 6.2 hours half-life,
 #' # ... probability at least 1e-4
 #' search_results <- search_phot_by_E(1, 1.2, 6 * 3600, 6.2 * 3600, 1e-4)
 #'
 #' # between 0.1 and 0.15 MeV, between 1 and 3 million years half-life
 #' search_results <- search_phot_by_E(0.1, 0.15, 1e6 * 3.153e7, 3e6 * 3.153e7)
+#' }
 #' @return search results in order of half-life. Recommend assigning
 #' results to a viewable object, such as 'search_results'
 #'
@@ -30,6 +32,7 @@ search_phot_by_E <- function(E_min = 0, E_max = 10,
                              min_half_life_seconds = NULL,
                              max_half_life_seconds = NULL,
                              min_prob = 0) {
+  .Deprecated("RN_search_phot_by_E")
   # photon search
   p <- RadData::ICRP_07.RAD %>%
     dplyr::filter(.data$is_photon == TRUE) %>%
